@@ -38,7 +38,7 @@ main(int argc, char **argv)
         ulong m = lyndon_factorization( W, n, F );
 //        S[m] += 1;
 
-#ifndef TIMING
+#if !defined TIMING
         cout << " " << setw(4) << ct << ":";
         M.print("  ", true );
 
