@@ -225,6 +225,8 @@
 #include "comb/is-setpart-ccf-perm.h"
 #include "comb/is-zero-map-rgs.h"
 #include "comb/print-zero-map-rgs.h"
+// multiset partitions:
+#include "comb/msetpart.h"
 
 
 //: ascent sequences, descent sequences, isoscent sequences:
